package ava.parser

sealed trait Token

object Token:
  /** Most tokens are generic tokens. They represent some arbitrary grouping of
    * characters that will be refined later.
    *
    * @param value
    *   The token value.
    */
  case class Generic(value: String) extends Token

  /** Comments are detected at time of tokenization, and are arbitrary strings.
    *
    * @param value
    *   The comment value.
    */
  case class Comment(value: String) extends Token

  /** The '(' character.
    */
  case object OpenParen extends Token

  /** The ')' character.
    */
  case object CloseParen extends Token

  /** The '.' character.
    */
  case object Dot extends Token

  /** The ',' character.
    */
  case object Comma extends Token

  /** The '"' character.
    */
  case object DoubleQuote extends Token

  /** The ''' character.
    */
  case object SingleQuote extends Token

  /** The ':' character.
    */
  case object Colon extends Token

  /** The '#' character.
    */
  case object Tuple extends Token
end Token
